# notebook

A new VDK plugin which will support running data jobs which consists of .ipynb files.
You can see [VDK Jupyter Integration VEP](https://github.com/vmware/versatile-data-kit/blob/main/specs/vep-994-jupyter-notebook-integration/README.md)

TODO: what the project is about, what is its purpose

## Usage
To install the plugin you need to run:
```
pip install vdk-notebook
```

### Configuration
No specific notebook configurations are needed currently.

### Example

TODO

### Testing
Testing this plugin locally requires installing the dependencies listed in vdk-plugins/vdk-notebook/requirements.txt

Run
```
pip install -r requirements.txt
```
## Architecture
See the [vdk enhancement proposal spec here](https://github.com/vmware/versatile-data-kit/blob/main/specs/vep-994-jupyter-notebook-integration/README.md)
